pub struct AgentApprovalTrustStatus {
pub key_source: ApprovalTrustSource,
pub last_refresh_at: Option<String>,
pub credential_expires_at: Option<String>,
}Expand description
Approval trust metadata reported alongside agent heartbeats.
Fields
key_source: ApprovalTrustSourceWhether trust was refreshed online or loaded from cache.
last_refresh_at: Option<String>RFC3339 timestamp for the last successful key refresh, when known.
credential_expires_at: Option<String>RFC3339 credential expiry timestamp, when available.